==> mupen64plus-core_1.99.4.orig.tar.gz: m64p_uninstall.sh <==
#!/bin/bash
#/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
# *   Mupen64plus - m64p_uninstall.sh                                       *
# *   Mupen64Plus homepage: http://code.google.com/p/mupen64plus/           *
# *   Copyright (C) 2009 Richard Goedeken                                   *
# *                                                                         *
# *   This program is free software; you can redistribute it and/or modify  *
# *   it under the terms of the GNU General Public License as published by  *
# *   the Free Software Foundation; either version 2 of the License, or     *
# *   (at your option) any later version.                                   *
# *                                                                         *
# *   This program is distributed in the hope that it will be useful,       *
# *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
# *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
# *   GNU General Public License for more details.                          *
# *                                                                         *
# *   You should have received a copy of the GNU General Public License     *
# *   along with this program; if not, write to the                         *
# *   Free Software Foundation, Inc.,                                       *
# *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
# * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

# terminate the script if any commands return a non-zero error code
set -e

echo "************************************ Removing core library"
make -C source/mupen64plus-core/projects/unix uninstall $@

echo "************************************ Removing console front-end"
make -C source/mupen64plus-ui-console/projects/unix uninstall $@

echo "************************************ Removing audio plugin"
make -C source/mupen64plus-audio-sdl/projects/unix uninstall $@

echo "************************************ Removing input plugin"
make -C source/mupen64plus-input-sdl/projects/unix uninstall $@

echo "************************************ Removing RSP plugin"
make -C source/mupen64plus-rsp-hle/projects/unix uninstall $@

echo "************************************ Removing video plugin"
make -C source/mupen64plus-video-rice/projects/unix uninstall $@

==> mupen64plus-core_1.99.5.orig.tar.gz: m64p_uninstall.sh <==
#!/bin/sh
#/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
# *   Mupen64plus - m64p_uninstall.sh                                       *
# *   Mupen64Plus homepage: http://code.google.com/p/mupen64plus/           *
# *   Copyright (C) 2009 Richard Goedeken                                   *
# *                                                                         *
# *   This program is free software; you can redistribute it and/or modify  *
# *   it under the terms of the GNU General Public License as published by  *
# *   the Free Software Foundation; either version 2 of the License, or     *
# *   (at your option) any later version.                                   *
# *                                                                         *
# *   This program is distributed in the hope that it will be useful,       *
# *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
# *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
# *   GNU General Public License for more details.                          *
# *                                                                         *
# *   You should have received a copy of the GNU General Public License     *
# *   along with this program; if not, write to the                         *
# *   Free Software Foundation, Inc.,                                       *
# *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
# * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

# terminate the script if any commands return a non-zero error code
set -e

if [ -z "$MAKE" ]; then
	MAKE=make
fi

echo "************************************ Removing core library"
"$MAKE" -C source/mupen64plus-core/projects/unix uninstall $@

echo "************************************ Removing console front-end"
"$MAKE" -C source/mupen64plus-ui-console/projects/unix uninstall $@

echo "************************************ Removing audio plugin"
"$MAKE" -C source/mupen64plus-audio-sdl/projects/unix uninstall $@

echo "************************************ Removing input plugin"
"$MAKE" -C source/mupen64plus-input-sdl/projects/unix uninstall $@

echo "************************************ Removing RSP plugin"
"$MAKE" -C source/mupen64plus-rsp-hle/projects/unix uninstall $@

echo "************************************ Removing video plugin"
"$MAKE" -C source/mupen64plus-video-rice/projects/unix uninstall $@
